# janginfo_organizer

## Table of Contents
  * [Installation](#installation)
  * [Quick start](#quick-start)
  * [Instruction](#instruction)
  * [Features](#features)
  
## Installation

Download using pip via pypi.

```bash
$ pip install janginfo_organizer
```
(Mac/homebrew users may need to use ``pip3``)

## Quick start
```
$ janginfo_organizer 'fasta' 'genbank' 'sernum'
// -o 'output file name' (optional)

Ex)
$ janginfo_organizer Dhansenii1.fa Dhansenii1.gbk F-Deb-han-1 -o 1_Dhansenii1
```

## Instruction

This tool was uploaded by the request of Dong Min Han.

Additional source code was uploaded in version 1.1.0.

```
$ tig_rename 'fasta'
// -o 'output file name' (optional)

Ex)
$ tig_rename Dhansenii1.fa
```

Dong Min Han, I wish you a speedy return from work.


## Features
  * Python script to organize the functional annotation output to excel output
